complete -c miniserve -l temp-directory -d 'The path to where file uploads will be written to before being moved to their correct location. It\'s wise to make sure that this directory will be written to disk and not into memory' -r -F
complete -c miniserve -l index -d 'The name of a directory index file to serve, like "index.html"' -r -F
complete -c miniserve -s p -l port -d 'Port to use' -r
complete -c miniserve -s i -l interfaces -d 'Interface to listen on' -r
complete -c miniserve -l workers -d 'Number of server workers' -r
complete -c miniserve -s a -l auth -d 'Set authentication' -r
complete -c miniserve -l auth-file -d 'Read authentication values from a file' -r -F
complete -c miniserve -l route-prefix -d 'Use a specific route prefix' -r
complete -c miniserve -s S -l default-sorting-method -d 'Default sorting method for file list' -r -f -a "name\t'Sort by name'
size\t'Sort by size'
date\t'Sort by last modification date (natural sort: follows alphanumerical order)'"
complete -c miniserve -s O -l default-sorting-order -d 'Default sorting order for file list' -r -f -a "asc\t'Ascending order'
desc\t'Descending order'"
complete -c miniserve -s c -l color-scheme -d 'Default color scheme' -r -f -a "squirrel\t''
archlinux\t''
ayu-dark\t''
zenburn\t''
monokai\t''"
complete -c miniserve -s d -l color-scheme-dark -d 'Default color scheme' -r -f -a "squirrel\t''
archlinux\t''
ayu-dark\t''
zenburn\t''
monokai\t''"
complete -c miniserve -s u -l upload-files -d 'Enable file uploading (and optionally specify for which directory)' -r -F
complete -c miniserve -l web-upload-files-concurrency -d 'Configure amount of concurrent uploads when visiting the website. Must have upload-files option enabled for this setting to matter' -r
complete -c miniserve -l chmod -d 'Set unix file permissions of uploaded files' -r
complete -c miniserve -s m -l media-type -d 'Specify uploadable media types' -r -f -a "image\t''
audio\t''
video\t''"
complete -c miniserve -s M -l raw-media-type -d 'Directly specify the uploadable media type expression' -r
complete -c miniserve -s o -l on-duplicate-files -d 'What to do if existing files with same name is present during file upload' -r -f -a "error\t''
overwrite\t''
rename\t''"
complete -c miniserve -s R -l rm-files -d 'Enable file and directory deletion (and optionally specify for which directory)' -r -f -a "(__fish_complete_directories)"
complete -c miniserve -s t -l title -d 'Shown instead of host in page title and heading' -r
complete -c miniserve -l header -d 'Inserts custom headers into the responses. Specify each header as a \'Header:Value\' pair. This parameter can be used multiple times to add multiple headers' -r
complete -c miniserve -l print-completions -d 'Generate completion file for a shell' -r -f -a "bash\t''
elvish\t''
fish\t''
powershell\t''
zsh\t''"
complete -c miniserve -l tls-cert -d 'TLS certificate to use' -r -F
complete -c miniserve -l tls-key -d 'TLS private key to use' -r -F
complete -c miniserve -l size-display -d 'Show served file size in exact bytes' -r -f -a "human\t''
exact\t''"
complete -c miniserve -l file-external-url -d 'Optional external URL (e.g., \'http://external.example.com:8081\') prepended to file links in listings' -r
complete -c miniserve -l log-color -d 'Set the color style of the log output' -r -f -a "auto\t''
always\t''
never\t''"
complete -c miniserve -s v -l verbose -d 'Be verbose, includes emitting access logs'
complete -c miniserve -l spa -d 'Activate SPA (Single Page Application) mode'
complete -c miniserve -l quiet -d 'Reduce output and silence warnings'
complete -c miniserve -l pretty-urls -d 'Activate Pretty URLs mode'
complete -c miniserve -l random-route -d 'Generate a random 6-hexdigit route'
complete -c miniserve -s P -l no-symlinks -d 'Hide symlinks in listing and prevent them from being followed'
complete -c miniserve -s H -l hidden -d 'Show hidden files'
complete -c miniserve -s q -l qrcode -d 'Enable QR code display'
complete -c miniserve -l directory-size -d 'Enable recursive directory size calculation'
complete -c miniserve -s U -l mkdir -d 'Enable creating directories'
complete -c miniserve -l pastebin -d 'Enable creating pastebin \'pastes\''
complete -c miniserve -s r -l enable-tar -d 'Enable uncompressed tar archive generation'
complete -c miniserve -s g -l enable-tar-gz -d 'Enable gz-compressed tar archive generation'
complete -c miniserve -s z -l enable-zip -d 'Enable zip archive generation'
complete -c miniserve -s C -l compress-response -d 'Compress response'
complete -c miniserve -s D -l dirs-first -d 'List directories first'
complete -c miniserve -s l -l show-symlink-info -d 'Visualize symlinks in directory listing'
complete -c miniserve -s F -l hide-version-footer -d 'Hide version footer'
complete -c miniserve -l hide-theme-selector -d 'Hide theme selector'
complete -c miniserve -s W -l show-wget-footer -d 'If enabled, display a wget command to recursively download the current directory'
complete -c miniserve -l print-manpage -d 'Generate man page'
complete -c miniserve -l readme -d 'Enable README.md rendering in directories'
complete -c miniserve -s I -l disable-indexing -d 'Disable indexing'
complete -c miniserve -l enable-webdav -d 'Enable read-only WebDAV support (PROPFIND requests)'
complete -c miniserve -s h -l help -d 'Print help (see more with \'--help\')'
complete -c miniserve -s V -l version -d 'Print version'
